@@ -13,8 +13,8 @@ require DynaLoader;
 
 use vars qw(@ISA $VERSION $XS_VERSION $CONFIG $DEBUG);
 
-$VERSION = '1.08_01';
-$XS_VERSION = "1.08";
+$VERSION = '1.08_02';
+$XS_VERSION = "1.08_02";
 @ISA = qw(IO::Handle);
 
 eval { local $^W = 0; undef local $SIG{__DIE__}; require IO::Stty };
@@ -99,7 +99,7 @@ IO::Tty - Low-level allocate a pseudo-Tty, import constants.
 
 =head1 VERSION
 
-1.08
+1.08_02
 
 =head1 SYNOPSIS
 
